==> kcommands-1.0.0.tgz: package/README.md <==
# Installation
```> npm install kaizcommands```
# For latest version
```
> npm install kaizcommands@latest
```

<div align="center">
  <p>
    <a href="https://nodei.co/npm/kcommands
/"><img src="https://nodei.co/npm/kcommands.png?downloads=true&stars=true" alt="NPM Info" /></a>
  </p>
</div>

# Functions
```AsciiDoc
KCommandsTicketSystem:: Create ticket
```
## KCommandsTicketSystem
```js
const { KCommandsTicketSystem } = require('KCommands')

//change to your commands handler
module.exports = {
    name: "openticket",
    aliases: ['ticket', 'open']
    run: async (client, message, args) => {
        const ticket = new KCommandsTicketSystem({
            //setup
            //send this message in channel use command
            channelmsg: "Hi, your ticket is {channelMentions}", // {channelMentions} = #channelname, {channelName} = channel name, {channelID} = channl_id
            // send this message in ticket when create
            ticketmsg: "Hello {userMentions}, how can we help you", // {userMentions} = @username, {userName} = username, {userID} = user_id
            ticketname: `ticket-${message.author.tag}`, //ticket name
            lock: "🔒", //lock emoji emoji
            delete: "⛔", //delete ticket emoji
            transcript: true, // send transcript when lock ticket
            transcriptchannelid: "859259154690605107", // send transcript in channel with id
        })
        ticket.openTicket(client, message)  //create new ticket, options are client (your client in index.js) and message (keep this, DO NOT CHANGE)
    }
}
```

==> kcommands-1.0.2.tgz: package/README.md <==
# Installation
```> npm install kaizcommands```
# For latest version
```
> npm install kaizcommands@latest
```

<div align="center">
  <p>
    <a href="https://nodei.co/npm/kcommands
/"><img src="https://nodei.co/npm/kcommands.png?downloads=true&stars=true" alt="NPM Info" /></a>
  </p>
</div>

# Functions
```AsciiDoc
KCommandsTicketSystem:: Create ticket
```
## KCommandsTicketSystem
```js
const { KCommandsTicketSystem } = require('KCommands')

//change to your commands handler
module.exports = {
    name: "openticket",
    aliases: ['ticket', 'open']
    run: async (client, message, args) => {
        const ticket = new KCommandsTicketSystem({
            //setup
            //send this message in channel use command
            channelmsg: "Hi, your ticket is {channelMentions}", // {channelMentions} = #channelname, {channelName} = channel name, {channelID} = channel_id
            // send this message in ticket when create
            ticketmsg: "Hello {userMentions}, how can we help you", // {userMentions} = @username, {userName} = username, {userID} = user_id
            ticketname: `ticket-${message.author.tag}`, //ticket name
            lock: "🔒", //lock emoji emoji
            delete: "⛔", //delete ticket emoji
            transcript: true, // send transcript when lock ticket
            transcriptchannelid: "859259154690605107", // send transcript in channel with id
        })
        ticket.openTicket(client, message)  //create new ticket, options are client (your client in index.js) and message (keep this, DO NOT CHANGE)
    }
}
```
